/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef jelzpnh
#define jelzpnh

#include <QObject>
#include <QXmlDefaultHandler>
#include <QMutex>

#include "Aux.h"
#include "Szines.h"
#include "con.h"

class QTimer;
class atalak : public QXmlDefaultHandler
<%
        public:
                atalak();

                bool startElement(const QString&, const QString&, const QString&, const QXmlAttributes&);
                bool endElement(const QString&, const QString&, const QString&);
                bool characters(const QString &fldlgz);

                QString prmz;
		QStringList kitzjl;
%>;

class prmza;
class bndkli;
class jelzpn: public QObject
<%
	Q_OBJECT

	signals:

		void synchro(const zagv&);

		void jvsltz(const QString&, int);

	public:
		jelzpn(QObject *felvnl);
		~jelzpn();

		QString gyrtmn;
		QString tljsn;
		QString tiszta;
		QString ugyex;

		bool hatter;

		void brndez();
		bool elrdnz;

		void fajta();
		void lecke();

		bool kesztm(QString);
		bool kitolt(const QString&);
		void marka();
		bool kiallt(const QString &akdaly);

		void muri();
		void detto();

		int kapod(int cel=0, int dolog=0, bool kltzik=0);

		void fhlhjt(int id1, int id2);
		bool csals(int id1, int id2);
		void jo(int alkt);
		void megir(int alkt);
		void korrkt(int alkt, int elodez=0);
		void lep(int alkt, int elodez=0);

		void ceco(int zandek, int targy, int jlnrdz);
		int ellqts(int zandek);
		int mgmozt;
		int alafng;
		void leir(int);
		QList<int> nagy();
		int fortum(int lnmtat);
		void rabir();
		void mozog();
		double mzgat;

		QColor kidlgz;
		QString mgmnkl;

		int ir;

		int amkzrs;
		QTimer *oztaly;
		QHash<int, prmza*> kket;
		QList<QPoint> eler;
		QList<int> hatved;

		QList<szn> munka;
		QList<elgy*> kitzjl;

		int lemasl();

		void rgsztg(const QString &kelt, const QString &sima, const QString &kivalt);

		int pllnts;
		int prmz(int lnmtat);
		int torekv(int lnmtat);
		bndkli* ezeltt(int);
		int hatl();

		void hatlja();
		void kulso();

		QString kivitl();
		QString meglns;

		prmza* operator+(const int x);

		void mgzerz(int, int);

		void tglalp(int lnmtat, int lmzdul);
		QMutex bunda;

	public slots:
		void kapni();
		void tekntt();
%>;

QIcon vmrgem(const QString& sima, int tamla=32);

#endif

